/*******************************************KOT**************************************************************/
/*	Programm zur Koordinatentransformation der Geschwindigkeitsmesswerte auf eine gemeinsame Ebene orthogonal 
	zum Stromfaden des gesamten Fließquerschnittes. Die Drehwinkel aller Messpunkte richten sich nach Randbe-
	dingung, die im Kapitel 2 detailliert eroertert wurden.
	Eingabe sind die Mittelwertdateien der Messpunkte und die Messpunktdateien. 
	Ausgabe sind eine koordinatentransformierte Mittelwertdatei und die koordinatentransformierte Messpunktdateien */

#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <math.h>

/*	Hauptprogramm mit Argumenten aus dem Projekt ADDV	*/

main(int argc, char *argv[]){
	
	FILE *eingabe1,*eingabe2,*ausgabe1,*ausgabe2;
	char pfad[255], zielpfad[255], y_pfad[255], zy_pfad[255];
	char lamellenordner[5], lamellenpkt[5];
	char mw_datei[255], mp_datei[255], kt_datei[255], tp_datei[255];
	char mw_zeile[100], mp_zeile[100];
	double t, y, z, vxa, vya, vza, vxn, vyn, vzn,S_vxn,S_vyn,S_vzn;
	double S_vxa_mit=0, S_vya_mit=0, S_vza_mit=0, S_vxm_mit=0;
	double vxa_mittel, vya_mittel, vza_mittel, vxm_mittel, vxn_mittel, vyn_mittel, vzn_mittel;
	double vxa_qmit, vya_qmit, vza_qmit, vxm_qmit;
	double alpha, beta, anzahl=0;
	int i,j,k,l,n=9,m=25,o,weiter;

/* Abkuerzungen: mw Mittelwert; mp Mittelpunkt; kot kt koordinatentransformiert; tp transformierter Punkt; S Summe; mit Mittel-; qmit Querschnittsmittel */
	
	sprintf(pfad,"%s",argv[1]);							/* Einlesen des Ordners */
	
	strcpy(mw_datei,pfad);
	strcat(mw_datei,"/Punktmittel.gem");
	
	eingabe1=fopen(mw_datei,"r");								/* Oeffnen der Mittelwertsdatei */
	
	sprintf(zielpfad,"%s",argv[2]);		/* Einlesen des Zielpfades */
	strcat(zielpfad,".kot");
	
/* Bestimmung der erforderlichen Drehwinkel zur Transformation der Mess- und Mittelwerte in hauptstroemungsorthogonales KO-System */
	
	weiter=feof(eingabe1);							/* Bildung der Querschnittsmittel (Geschwindigkeit) des Messprofiles */
	while(weiter==0){
		fgets(mw_zeile,100,eingabe1);
		weiter=feof(eingabe1);
		sscanf(mw_zeile,"%lf%lf%lf%lf%lf",&y,&z,&vxa_mittel,&vya_mittel,&vza_mittel);
		if(weiter==0){
			S_vxa_mit+=vxa_mittel;					//Summenbildung
			S_vya_mit+=vya_mittel;
			S_vza_mit+=vza_mittel;
			anzahl++;						//Zählen der Messwerte
		}
	}
	vxa_qmit=S_vxa_mit/anzahl;						/* Berechnung des Querschnittsmittels von vx vy vz */
	vya_qmit=S_vya_mit/anzahl;
	vza_qmit=S_vza_mit/anzahl;
	
	alpha=atan2(vya_qmit,vxa_qmit);						/* Berechnung des Drehwinkels der x-y-Ebene */
	
	fseek(eingabe1,0L,SEEK_SET);								/* Zurueck zu Dateianfang */
	anzahl=0;
	weiter=feof(eingabe1);					/* Berechnung des vx-Mittels nach erfolgter Drehung der x-y-Ebene */
	while(weiter==0){
		fgets(mw_zeile,100,eingabe1);
		weiter=feof(eingabe1);
		sscanf(mw_zeile,"%lf%lf%lf%lf%lf",&y,&z,&vxa_mittel,&vya_mittel,&vza_mittel);
		if(weiter==0){
			vxm_mittel=vxa_mittel*cos(alpha)+vya_mittel*sin(alpha);		/* Berechnung Zwischenwert der vx-Komp. */
			S_vxm_mit+=vxm_mittel;						//Summenbildung der neuen x-Komponenten (Hilfsgroesse)
			anzahl++;
		}
	}
	fclose(eingabe1);
	vxm_qmit=S_vxm_mit/anzahl;							//Mittelwert der neuen x-Komponenten (Hilfsgroesse)
	
	beta=atan2(vza_qmit,vxm_qmit);							/* Berechnung des Drehwinkels der x-z-Ebene */
	
	ausgabe1=fopen(zielpfad,"w");			/* Anlegen der transformierten Mittelwertdatei */
	
	/* Erstellung der koordinatentransformierten Messpunktdateien */
	
	for(i=0;i<=m;i++){						/* Schleife fuer 1. Lamellenwert */
		for(j=0;j<=n;j++){					/* Schleife fuer 2. Lamellenwert */
		for(k=0;k<=n;k++){					/* Schleife fuer 3. Lamellenwert (Zweite Nachkommastelle) */
		
			strcpy(y_pfad,pfad);				/* Kopieren und Ueberschreiben des y-zielpfad mit zielpfad */
			sprintf(lamellenordner,"/%i_%i%i",i,j,k);
			strcat(y_pfad,lamellenordner);			/* Lamellenordner an Pfad anhaengen */
			
			for(l=1;l<=m;l++){				/* Schleife fuer Lamellenpunkt */ 
			
				strcpy(zy_pfad,y_pfad);			/* Kopieren bzw. Ueberschreiben des zypfad mit ypfad */
				sprintf(lamellenpkt,"/%i",l);
				strcat(zy_pfad,lamellenpkt);		/* Messpunkt an Pfad anhaengen */
				
				strcpy(mp_datei,zy_pfad);
				strcat(mp_datei,".mp");
			
				eingabe2=fopen(mp_datei,"r");		/* Oeffnen der mp.-Datei */
				
				
				if(eingabe2!=NULL){
					
					strcpy(tp_datei,zy_pfad);
					strcat(tp_datei,".tp");
					ausgabe2=fopen(tp_datei,"w");	/* Anlegen der neuen Datei mit transformierten v-Punkten */
					
					S_vxn=0.0;
					S_vyn=0.0;
					S_vzn=0.0;
					o=0;
					weiter=feof(eingabe2);
					while(weiter==0){
						fgets(mp_zeile,100,eingabe2);
						weiter=feof(eingabe2);
						if(weiter==0){
							sscanf(mp_zeile,"%lf%lf%lf%lf%lf%lf",&t,&y,&z,&vxa,&vya,&vza);
							vxn=(vxa*cos(alpha)+vya*sin(alpha))*cos(beta)+vza*sin(beta);	//Berechnung der transformierten u-Komponente
							S_vxn+=vxn;
							vyn=vya*cos(alpha)-vxa*sin(alpha);				//Berechnen der transformierten v-Komponente
							S_vyn+=vyn;
							vzn=vza*cos(beta)-(vxa*cos(alpha)+vya*sin(alpha))*sin(beta);	//Berechnen der transformierten w-Komponente
							S_vzn+=vzn;
							o++;
							fprintf(ausgabe2,"%lf\t%lf\t%lf\t%lf\t%lf\t%lf\n",t, y ,z ,vxn ,vyn ,vzn);
						}
					}
					/* Erstellung der transformierten Mittelwertdatei */
					vxn_mittel=S_vxn/o;
					vyn_mittel=S_vyn/o;
					vzn_mittel=S_vzn/o;
					fprintf(ausgabe1,"%lf\t%lf\t%lf\t%lf\t%lf\n",y ,z ,vxn_mittel ,vyn_mittel ,vzn_mittel);
					
					fclose(eingabe2);
					fclose(ausgabe2);
				}
			}
		}
		}
	}
	/*fprintf(ausgabe1,"alpha=%lf\tbeta=%lf\n",alpha,beta);*/
	fclose(ausgabe1);
}
